#[embed_doc_image]Expand description
Produces a doc string for inclusion in Markdown documentation.
Please see the crate-level documentation for usage instructions.
#[embed_doc_image]Produces a doc string for inclusion in Markdown documentation.
Please see the crate-level documentation for usage instructions.